@@ -105,6 +105,7 @@ mod primitives;
 pub use oversized::Bitmap1024;
 pub use oversized::Bitmap2048;
 pub use oversized::Bitmap256;
+pub use oversized::Bitmap4096;
 pub use oversized::Bitmap512;
 pub use oversized::BitmapKB;
 pub use primitives::Bitmap128;
@@ -113,3 +114,4 @@ pub use primitives::Bitmap32;
 pub use primitives::Bitmap64;
 pub use primitives::Bitmap8;
 pub use primitives::BitmapArch;
+pub use primitives::BitmapSize;
