@@ -1,11 +1,13 @@
 mod bitmap_1024;
 mod bitmap_2048;
 mod bitmap_256;
+mod bitmap_4096;
 mod bitmap_512;
 mod bitmap_kb;
 
 pub use bitmap_1024::Bitmap1024;
 pub use bitmap_2048::Bitmap2048;
 pub use bitmap_256::Bitmap256;
+pub use bitmap_4096::Bitmap4096;
 pub use bitmap_512::Bitmap512;
 pub use bitmap_kb::BitmapKB;
