@@ -1,7 +1,8 @@
+use super::BitmapSize;
 use core::fmt::Formatter;
 use serde::{Deserialize, Serialize};
 use std::{
-    fmt::Display,
+    fmt::{Debug, Display},
     mem,
     ops::{
         Add, AddAssign, BitAnd, BitAndAssign, BitOr, BitOrAssign, BitXor, BitXorAssign, Deref, Div,
@@ -9,8 +10,6 @@ use std::{
     },
 };
 
-const MAP_LENGTH: usize = mem::size_of::<u64>() * 8;
-
 /// A bitmap of length 64.
 ///
 /// # Examples
@@ -42,20 +41,64 @@ const MAP_LENGTH: usize = mem::size_of::<u64>() * 8;
 /// // Or you could use the deref operator for an even easier conversion
 /// println!("Bitmap value: {}", *bitmap);
 /// ```
-#[derive(
-    PartialEq, Eq, PartialOrd, Ord, Clone, Copy, Hash, Debug, Default, Serialize, Deserialize,
-)]
+#[derive(PartialEq, Eq, PartialOrd, Ord, Clone, Copy, Hash, Default, Serialize, Deserialize)]
 pub struct Bitmap64(u64);
 
 impl Bitmap64 {
     pub fn capacity() -> usize {
-        MAP_LENGTH
+        Bitmap64::MAP_LENGTH
     }
 
     pub fn to_u64(&self) -> u64 {
         self.0
     }
 
+    /// Creates a new bitmap with all bits set to the given value.
+    ///
+    /// ## Example
+    ///
+    /// ```rust
+    /// use fixed_bitmaps::Bitmap64;
+    ///
+    /// let a = Bitmap64::new(true);
+    /// assert_eq!(*a, u64::MAX);
+    ///
+    /// let b = Bitmap64::new(false);
+    /// assert_eq!(*b, 0);
+    /// ```
+    pub fn new(value: bool) -> Bitmap64 {
+        Bitmap64(if value { u64::MAX } else { 0 })
+    }
+
+    /// Create a new bitmap that has its bits set from `begin` (inclusive) to `end` (exclusive).
+    /// If begin is greater than the map length or end is 0, will return a bitmap with all bits set to
+    /// the opposite of value.
+    ///
+    /// ## Example
+    ///
+    /// ```rust
+    /// use fixed_bitmaps::Bitmap64;
+    ///
+    /// let a = Bitmap64::create_bit_mask(3, 7, true);
+    /// assert_eq!(*a, 0b1111000);
+    ///
+    /// let b = Bitmap64::create_bit_mask(3, 6, false); // Results in 1..1000111
+    /// assert_eq!(b, Bitmap64::new(true) ^ 0b111000);
+    /// ```
+    pub fn create_bit_mask(begin: usize, end: usize, value: bool) -> Bitmap64 {
+        if value {
+            if begin >= Bitmap64::MAP_LENGTH || end < 1 {
+                Bitmap64(0)
+            } else if end >= Bitmap64::MAP_LENGTH {
+                Bitmap64(u64::MAX << begin)
+            } else {
+                Bitmap64(u64::MAX << begin & u64::MAX >> Bitmap64::MAP_LENGTH - end)
+            }
+        } else {
+            !Bitmap64::create_bit_mask(begin, end, true)
+        }
+    }
+
     /// Creates a new, empty `Bitmap64`, and sets the desired index before returning.
     ///
     /// ```rust
@@ -71,7 +114,7 @@ impl Bitmap64 {
     /// assert_eq!(a, b);
     /// ```
     pub fn from_set(index: usize) -> Option<Bitmap64> {
-        if index >= MAP_LENGTH {
+        if index >= Bitmap64::MAP_LENGTH {
             return None;
         }
 
@@ -101,10 +144,10 @@ impl Bitmap64 {
     /// assert_eq!(*bitmap, 16);
     /// ```
     pub fn set(&mut self, index: usize, value: bool) -> Result<(), String> {
-        if index >= MAP_LENGTH {
+        if index >= Bitmap64::MAP_LENGTH {
             return Err(String::from(
                 "Tried to set bit that's out of range of the bitmap (range: ",
-            ) + &MAP_LENGTH.to_string()
+            ) + &Bitmap64::MAP_LENGTH.to_string()
                 + ", index: "
                 + &index.to_string()
                 + ")");
@@ -121,6 +164,30 @@ impl Bitmap64 {
         Ok(())
     }
 
+    /// Set bits from begin (inclusive) to end (exclusive) to the given value.
+    ///
+    /// ## Example
+    ///
+    /// ```rust
+    /// use fixed_bitmaps::Bitmap64;
+    ///
+    /// let mut bitmap = Bitmap64::default();
+    /// assert_eq!(*bitmap, 0);
+    ///
+    /// bitmap.set_range(2, 7, true);
+    /// assert_eq!(*bitmap, 0b1111100);
+    ///
+    /// bitmap.set_range(3, 5, false);
+    /// assert_eq!(*bitmap, 0b1100100);
+    /// ```
+    pub fn set_range(&mut self, begin: usize, end: usize, value: bool) {
+        if value {
+            *self |= Bitmap64::create_bit_mask(begin, end, true);
+        } else {
+            *self &= Bitmap64::create_bit_mask(begin, end, false);
+        }
+    }
+
     /// Gets the bit at the given index. Note that indexing starts at 0.
     ///
     /// ## Returns
@@ -143,10 +210,10 @@ impl Bitmap64 {
     /// assert_eq!(bitmap.get(3).unwrap(), true);
     /// ```
     pub fn get(&self, index: usize) -> Result<bool, String> {
-        if index >= MAP_LENGTH {
+        if index >= Bitmap64::MAP_LENGTH {
             return Err(String::from(
                 "Tried to get bit that's out of range of the bitmap (range: ",
-            ) + &MAP_LENGTH.to_string()
+            ) + &Bitmap64::MAP_LENGTH.to_string()
                 + ", index: "
                 + &index.to_string()
                 + ")");
@@ -159,11 +226,13 @@ impl Bitmap64 {
 
 impl Display for Bitmap64 {
     fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), std::fmt::Error> {
-        let mut bitmap = String::new();
-        for i in 0..MAP_LENGTH {
-            bitmap.push_str(&(if self.0 & (1 << i) > 0 { 1 } else { 0 }).to_string());
-        }
-        write!(f, "{}", bitmap.chars().rev().collect::<String>())
+        write!(f, "{:b}", self.0)
+    }
+}
+
+impl Debug for Bitmap64 {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "Bitmap64({:X})", self.0)
     }
 }
 
@@ -173,6 +242,10 @@ impl From<u64> for Bitmap64 {
     }
 }
 
+impl BitmapSize for Bitmap64 {
+    const MAP_LENGTH: usize = mem::size_of::<u64>() * 8;
+}
+
 // Traits implementing bitwise operations between Bitmaps of the same type
 
 impl BitAnd for Bitmap64 {
